@@ -229,8 +229,8 @@ class MDSimulation():
             self.box_vectors = None
 
         # make sure the parmed has all the params
-        if len([i.type for i in parmed_structure.bonds if i.type == None]) > 0:
-            raise ValueError('Parmed object does not have all parameters')
+        # if len([i.type for i in parmed_structure.bonds if i.type == None]) > 0:
+        #     raise ValueError('Parmed object does not have all parameters')
 
         # match num atoms to num coordinates
         if len(parmed_structure.atoms) != len(self.positions):
