@@ -219,18 +219,35 @@ class SegmentMappingSim(MetadynamicSimulation):
                 #TODO come up with hueristic to pick more reliable energy cutoff and order estimate
                 saddle_traj, segment_frames = get_minimum_path_trajectory(CV_trace=CV_trace,
                                                              fes=fes,
-                                                             order=15,
+                                                             order=150,
                                                              CV_list=self.CV_list,
                                                              energy_cutoff=-5,
                                                              frames_per_minima=2,
                                                              traj=traj)
 
-                if len(saddle_traj)==0:
-                    raise ValueError('did not find any wells for this scan!')
-                print('found {} MFEP saddle points for use in segment mapping'.format(len(saddle_traj)))
+                if saddle_traj is not None:
+                    # slice traj for chosen frames
+                    self.segment_coords.append(saddle_traj.xyz)
+                else:
+                    #MFEP detection failed, take random set of frames the old way
+                    distance_targets = np.linspace(np.min(distances), self.unbound_distance, self.num_segs)
+                    segment_frames = []
+                    chosen_CVs = []
+                    for k, target in enumerate(distance_targets):
+                        idx = (np.abs(distances - target)).argmin()
+                        # if idx is already in the list, try 100 times to choose another with similar value
+                        counter = 0
+                        while idx in segment_frames and counter < 100:
+                            counter += 1
+                            target += random.randint(-100, 100) * .01
+                            idx = (np.abs(distances - target)).argmin()
+                        segment_frames.append(idx)
+                        chosen_CVs.append(distances[idx])
+                        print('choosing CV values {} {}'.format(idx, CVs[idx]))
 
-                # slice traj for chosen frames
-                self.segment_coords.append(saddle_traj.xyz)
+                    # load trajectory and slice for chosen frames
+                    traj = mdtraj.load_hdf5(os.path.join(self.cwd, self.traj_out))
+                    self.segment_coords.append(traj.xyz[segment_frames])
 
                 #now we have the coordinates we use for seeding, delete the bias file and previous objects
                 pattern = re.compile('bias(.*)\.npy')
@@ -422,7 +439,7 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
             current_energy = state.getPotentialEnergy()
 
             #load in new coordinates and get the new energy
-            chosen_replica = np.random.randint(self.num_replicas)
+            chosen_replica = np.random.randint(len(segment_coords))
             chosen_frame_index =  np.random.randint(len(segment_coords[chosen_replica]))
             proposed_frame = segment_coords[chosen_replica][chosen_frame_index]
             self.simulation.context.setPositions(proposed_frame * unit.nanometers)
@@ -443,32 +460,33 @@ class SegmentMappingSimHREMD(SegmentMappingSim):
                 self.simulation.context.setPositions(current_positions)
             print('HREMD acceptance rate {}'.format(accepted/attempted))
 
-            #calc coverage, dG_std and detect convergence
-            coverage = calc_coverage(self.metaD.getFreeEnergy().value_in_unit(unit.kilocalorie_per_mole))
-            print('coverage is currently {:.2f}%'.format(coverage * 100))
-            with open(os.path.join(self.cwd,'dG_trace.pickle'),'rb') as handle:
-                dG_trace = pickle.load(handle)
+            if len(self.CV_list)>1:
+                #calc coverage, dG_std and detect convergence
+                coverage = calc_coverage(self.metaD.getFreeEnergy().value_in_unit(unit.kilocalorie_per_mole))
+                print('coverage is currently {:.2f}%'.format(coverage * 100))
+                with open(os.path.join(self.cwd,'dG_trace.pickle'),'rb') as handle:
+                    dG_trace = pickle.load(handle)
 
-            #get the rolling average dG displacement and variance of the production dG value trace over a limited range
-            window_steps = np.max([1,int(int(self.convergence_window / self.step_length)/int(self.fes_interval/self.step_length))])
-            # print('window steps, len(dG-trace)',window_steps,len(dG_trace))
+                #get the rolling average dG displacement and variance of the production dG value trace over a limited range
+                window_steps = np.max([1,int(int(self.convergence_window / self.step_length)/int(self.fes_interval/self.step_length))])
+                # print('window steps, len(dG-trace)',window_steps,len(dG_trace))
 
-            if len(dG_trace)>window_steps:
-                window_trace = dG_trace[len(dG_trace)-window_steps:]
-                dG_std = np.std(window_trace)
-                print('dG_std over the last {}: {}'.format(self.convergence_window,dG_std))
-                m_ave = moving_average(window_trace, np.max([1,int(len(window_trace)/3)]))
-                dG_displacement = np.max(m_ave) - np.min(m_ave)
-                print('dG_displacement over the last {}: {}'.format(self.convergence_window,dG_displacement))
+                if len(dG_trace)>window_steps:
+                    window_trace = dG_trace[len(dG_trace)-window_steps:]
+                    dG_std = np.std(window_trace)
+                    print('dG_std over the last {}: {}'.format(self.convergence_window,dG_std))
+                    m_ave = moving_average(window_trace, np.max([1,int(len(window_trace)/3)]))
+                    dG_displacement = np.max(m_ave) - np.min(m_ave)
+                    print('dG_displacement over the last {}: {}'.format(self.convergence_window,dG_displacement))
 
-            #convergence detected when there is significant coverage and dG std and dG rolling average displacement is low
-            if coverage > self.min_coverage_criteria and \
-                sim_time > self.min_production_time and \
-                dG_std < self.convergence_criteria and \
-                dG_displacement < self.dG_displacement_criteria:
-                print("""convergence detected! Final dG {}:, coverage 
-                      {}, dG_std: {}, dG_displacement: {}""".format(dG_trace[-1],coverage * 100,dG_std,dG_displacement))
-                continue_simulating= False
+                #convergence detected when there is significant coverage and dG std and dG rolling average displacement is low
+                if coverage > self.min_coverage_criteria and \
+                    sim_time > self.min_production_time and \
+                    dG_std < self.convergence_criteria and \
+                    dG_displacement < self.dG_displacement_criteria:
+                    print("""convergence detected! Final dG {}:, coverage 
+                          {}, dG_std: {}, dG_displacement: {}""".format(dG_trace[-1],coverage * 100,dG_std,dG_displacement))
+                    continue_simulating= False
 
             #or complete when max time is hit
             if sim_time>=self.max_production_time:
