@@ -550,7 +550,7 @@ def get_fes_minima(fes, order, energy_cutoff):
     for i in range(len(minimax[0])):
         x_direction.add((minimax[0][i], minimax[1][i]))
 
-    min_set = x_direction.union(y_direction)
+    min_set = x_direction.intersection(y_direction)
     min_set = list(min_set)
     x_mins = [min_set[i][0] for i in range(len(min_set))]
     y_mins = [min_set[i][1] for i in range(len(min_set))]
@@ -582,7 +582,11 @@ def get_minimum_path_trajectory(fes,CV_trace,CV_list,traj,order,energy_cutoff,fr
         print('minima {}: frame {}: fes value {}'.format(k,chosen_indices,fes[minimum[0],minimum[1]]))
         final_list.append(chosen_indices)
 
-    final_list = np.unique(np.concatenate(final_list))
-    print(final_list)
-    chosen_traj = traj[final_list]
-    return chosen_traj, frame_list
\ No newline at end of file
+    if len(final_list)==0:
+        print('did not find any MFEP points')
+        return None, None
+    else:
+        final_list = np.unique(np.concatenate(final_list))
+        print(final_list)
+        chosen_traj = traj[final_list]
+        return chosen_traj, frame_list
\ No newline at end of file
